"""
# jsii-code-samples

> An example jsii package authored in TypeScript that gets published as GitHub packages for Node.js, Python, Java and dotnet.

## License

This library is licensed under the MIT-0 License. See the LICENSE file.
"""
import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

from ._jsii import *


class HelloWorld(metaclass=jsii.JSIIMeta, jsii_type="jsii-code-samples.HelloWorld"):
    def __init__(self) -> None:
        jsii.create(HelloWorld, self, [])

    @jsii.member(jsii_name="fibonacci")
    def fibonacci(self, num: jsii.Number) -> jsii.Number:
        """
        :param num: -
        """
        return jsii.invoke(self, "fibonacci", [num])

    @jsii.member(jsii_name="sayHello")
    def say_hello(self, name: str) -> str:
        """
        :param name: -
        """
        return jsii.invoke(self, "sayHello", [name])


__all__ = [
    "HelloWorld",
]

publication.publish()



import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

__jsii_assembly__ = jsii.JSIIAssembly.load("jsii-code-samples", "0.0.1", __name__[0:-6], "jsii-code-samples@0.0.1.jsii.tgz")

__all__ = [
    "__jsii_assembly__",
]

publication.publish()



import json
import setuptools

kwargs = json.loads("""
{
    "name": "aws-jsiisamples.jsii-code-samples",
    "version": "0.0.1",
    "description": "Code samples that accompany the AWS blog post on jsii",
    "license": "MIT-0",
    "url": "https://github.com/aws-samples/jsii-code-samples#readme",
    "long_description_content_type": "text/markdown",
    "author": "Hari Pachuveetil <pachuvee@amazon.com>",
    "project_urls": {
        "Source": "https://github.com/aws-samples/jsii-code-samples.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_jsiisamples.jsii_code_samples",
        "aws_jsiisamples.jsii_code_samples._jsii"
    ],
    "package_data": {
        "aws_jsiisamples.jsii_code_samples._jsii": [
            "jsii-code-samples@0.0.1.jsii.tgz"
        ],
        "aws_jsiisamples.jsii_code_samples": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "jsii>=1.5.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Typing :: Typed"
    ]
}
""")

with open('README.md') as fp:
    kwargs['long_description'] = fp.read()


setuptools.setup(**kwargs)
